translate.services.lookupservice

Package translate :: Package services :: Module lookupservice |
[hide private]
[frames] | no frames]

# Module lookupservice

source code

Server program to serve messages over XML-RPC

As this is implemented using the base classes (see storage.base), the work is minimal to use this with any storage format that is implemented using the base classes. Strictly speaking, only an init... function needs to be registered.

Classes | [hide private]
| lookupRequestHandler Sets up the requested file for parsing
| lookupServer
| lookupOptionParser Parser that calls instantiates the lookupServer

Functions | [hide private]
inittbx(inputfile, columnorder=None) | source code
inittmx(inputfile, columnorder=None) | source code
initpo(inputfile, columnorder=None) | source code
initcsv(inputfile, columnorder=None) | source code
main() | source code

Imports: convert, tbx, tmx, po, csvl10n, match, multistring, SimpleXMLRPCServer, SimpleXMLRPCRequestHandler